;; Generated package description from isearch-mb.el  -*- no-byte-compile: t -*-
(define-package "isearch-mb" "0.4.0.20220316.200312" "Control isearch from the minibuffer" '((emacs "27.1")) :commit "a67f51b723f25716036de75b0c8943900e5d8fe8" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("matching") :url "https://github.com/astoff/isearch-mb")
